	block data cblkElemag


#include "Zelemagp.h"

	data 
     *	RecoilKineMinE /0.2d-3/,     !
     *  KnockOnRatio  /1.0d0/,       ! 
     *  AnihiE /30.e-3/,            ! Eposi < 30 MeV, anihilation considered
     *  X0 /365.667/,                ! radiation length of air in kg/m2
     *  Ecrit /81.e-3/,             ! critical energy of air in GeV
     *  MaxComptonE /1./,       ! compton is considered below 75 MeV
     *  MaxPhotoE /1.e-3/,            ! above this, PhotoElectric effect neg.
     *  MinPhotoProdE /150.e-3/,     ! below 150 MeV, no gp --> hadrons
     *	Es /19.3d-3/,                 ! scattering const. Note, not 21 MeV.
     *  Knockon /.true./,            ! knockon is considered. Obsolete
     *  PhotoProd /.false./,        ! gp--> hadrons not considered.
     *  Excom1 /1.0d-3/,                ! if Eg <=Excom1,  XCOM data is used for 
                                    ! compton/p.e/coherent .
     *  Excom1 /1.0d-3/,                ! if Eg <= Excom2, XCOM data for Pair cre.
     *  Moliere /2/                 ! Moliere scattering for non-electron 
	end
